;; Generated package description from tex-parens.el  -*- no-byte-compile: t -*-
(define-package "tex-parens" "0.6.0.20241029.61540" "Like lisp.el, but for tex" '((emacs "27.1")) :commit "e7d2d5b89a52503841bfeaa4f5bcbdf47b8b6dfc" :authors '(("Paul D. Nelson" . "nelson.paul.david@gmail.com")) :maintainer '("Paul D. Nelson" . "nelson.paul.david@gmail.com") :keywords '("tex" "convenience") :url "https://github.com/ultronozm/tex-parens.el")
